@@ -148,6 +148,11 @@ def parse_command_line(argv):
         dest='tag_docker_image',
         help='create a Docker image from the resulting container')
 
+    parser.add_argument('--fail-to-shell',
+                        dest='fail_to_shell',
+                        action='store_true',
+                        help='drop into an in-container Bash shell on failure')
+
     parser.add_argument(
         'emerge_target',
         metavar='CP|CPV|=CPV|@SET',
@@ -239,6 +244,7 @@ def build(config):
     container_make_profile = '/etc/make.profile'
     container_command_shared_prefix = [
         f'ln -s {shlex.quote(container_portdir)} {shlex.quote(container_portdir_dir_link_target)}',
+        'mkdir -p -m 0775 /run/lock',  # needed by e.g. pkg_postinst of app-text/docbook-xml-dtd
         'set -x',
 
         # This is to avoid access to potentially missing link /etc/portage/make.profile .
@@ -337,6 +343,11 @@ def build(config):
                     f'{emerge_quoted_flat} {rebuild_or_not} {install_or_not} {shlex.quote(config.emerge_target)}'  # noqa: E501
                 )
 
+            if config.fail_to_shell:
+                success_chain_flat = ' && '.join(step_commands)
+                step_commands = [f'{{ {{ {success_chain_flat} ; }} || {{ bash -i ; }} ; }}']
+                del success_chain_flat
+
             if container_name is not None:
                 # Cleanup symlinks that were created in previous steps, otherwise subsequent
                 # builds with --tag-docker-image will fail when the same symlinks are re-created
@@ -354,6 +365,8 @@ def build(config):
 
             docker_run_args = [
                 docker_container_lifecycle_arg,
+                '--mount',
+                'destination=/run,type=tmpfs,readonly=false,tmpfs-mode=755',
                 '-v',
                 f'{eventual_etc_portage}:/etc/portage:rw',
                 '-v',
@@ -373,9 +386,11 @@ def build(config):
             if config.interactive:
                 docker_run_args = ['-it'] + docker_run_args
 
+            delete_log = False
             try:
                 announce_and_call(['docker', 'run'] + docker_run_args,
                                   stdout=log_writer_process.stdin)
+                delete_log = True
 
                 if config.tag_docker_image is not None:
                     announce_and_call(
@@ -384,11 +399,11 @@ def build(config):
                 log_writer_process.stdin.close()
                 log_writer_process.wait()
 
-                with suppress(FileNotFoundError):
-                    os.remove(host_log_filename)
-                with suppress(OSError):
-                    os.rmdir(host_logdir__category__package)
-                    os.rmdir(host_logdir__category)
+                if delete_log:
+                    with suppress(OSError):
+                        os.remove(host_log_filename)
+                        os.rmdir(host_logdir__category__package)
+                        os.rmdir(host_logdir__category)
 
                 if config.tag_docker_image is not None:
                     announce_and_call(['docker', 'rm', container_name])
