@@ -2,6 +2,7 @@
 # Licensed under GNU Affero GPL version 3 or later
 
 import os
+import sys
 from io import StringIO
 from tempfile import TemporaryDirectory
 from textwrap import dedent
@@ -60,6 +61,7 @@ class ParsePackageBlockTest(TestCase):
 
 
 class AdjustIndexFileHeaderTest(TestCase):
+
     def test_replacement(self):
         original_dummy_header = dedent("""\
             PACKAGES: 758
@@ -81,6 +83,7 @@ class AdjustIndexFileHeaderTest(TestCase):
 
 
 class HasSafePackagePathTest(TestCase):
+
     @parameterized.expand([
         ('cat/pkg/pkg-123-1.xpak', True, 'healthy .xpak'),
         ('cat/pkg-123.tbz2', True, 'healthy .tbz2'),
@@ -94,6 +97,7 @@ class HasSafePackagePathTest(TestCase):
 
 
 class ReadPackagesIndexFileTest(TestCase):
+
     def test_success(self):
         expected_header = 'K1: v1'
         expected_packages_blocks = ['K2: v2', 'K3: v3', '']
@@ -114,6 +118,7 @@ class ReadPackagesIndexFileTest(TestCase):
 
 
 class RunDeleteTest(TestCase):
+
     @staticmethod
     def _create_empty_file(filename):
         os.makedirs(os.path.dirname(filename))
@@ -186,6 +191,7 @@ class RunDeleteTest(TestCase):
 
 
 class RunListTest(TestCase):
+
     @staticmethod
     def _run_list_with_config(config):
         with patch('sys.stdout', StringIO()) as stdout_mock:
@@ -230,6 +236,7 @@ class RunListTest(TestCase):
 
 
 class MainTest(TestCase):
+
     @parameterized.expand([
         ('gentoo-packages', '--help'),
         ('gentoo-packages', 'delete', '--help'),
@@ -240,7 +247,10 @@ class MainTest(TestCase):
             with self.assertRaises(SystemExit) as catcher:
                 main()
             self.assertEqual(catcher.exception.args, (0, ))  # i.e. success
-            self.assertIn('optional arguments:', stdout_mock.getvalue())
+            if sys.version_info >= (3, 10):
+                self.assertIn('options:', stdout_mock.getvalue())
+            else:
+                self.assertIn('optional arguments:', stdout_mock.getvalue())
 
     def test_list_failure_empty_directory(self):  # just something that touches beyond argparse
         with TemporaryDirectory() as tempdir:
